function [k,m]=feframe2(EI,EA,leng,mtot,T_e_b,T_e_t,beta,macc)

%--------------------------------------------------------------
%  Purpose:
%     Stiffness and mass matrices for the 2-d frame element
%     nodal dof {u_1 v_1 theta_1 u_2 v_2 theta_2}
%
%  Synopsis:
%     [k,m]=feframe2(el,xi,leng,area,rho,beta,ipt) 
%
%  Variable Description:
%     k - element stiffness matrix (size of 6x6)   
%     m - element mass matrix (size of 6x6)
%     EI - Bending stiffness  
%     EA - axial rigidity
%     leng - element length
%     mtot - total mass per unit length
%     T_e_b - effective tension in the element bottom
%     T_e_t - effective tension at element top
%     beta - angle between the local and global axes
%            is positive if the local axis is in the ccw direction from
%            the global axis
%
%   Created by Raed Lubbad
%   Last modified by Ingrid Simensen 10.06.15
%--------------------------------------------------------------------------


% Stiffness matrix at the local axis(Bending stiffness + Geometrical stiffness)
 a=EA/leng;
 c=EI/(leng^3);
 c1=T_e_b/(30*leng);
 c2 = (T_e_t - T_e_b)/(60*leng);
 kl=[a   0                                        0                                             -a     0                                          0;...
     0   12*c + (c1*36) + (36*c2)                 6*leng*c + (c1*3*leng) + (6*c2*leng)           0    -12* c + (c1*-36) + (-36*c2)                6*leng*c + (c1*3*leng) + (0*c2*leng);...
     0   6*leng*c + (c1*3*leng) + (6*c2*leng)     4*leng^2*c + (c1*4*leng^2) + (2*c2*leng^2)     0    -6*leng*c + (c1*-3*leng) + (-6*c2*leng)     2*leng^2*c + (c1*-leng^2) + (-1*c2*leng^2);...
    -a   0                                        0                                              a     0                                          0;...
     0  -12*c + (c1*-36) + (-36*c2)              -6*leng*c + (c1*-3*leng) + (-6*c2*leng)         0     12*c + (c1*36) + (36*c2)                  -6*leng*c + (c1*-3*leng) + (0*c2*leng);...
     0   6*leng*c + (c1*3*leng) + (0*c2*leng)     2*leng^2*c + (c1*-leng^2) + (-1*c2*leng^2)     0    -6*leng*c + (c1*-3*leng) + (0*c2*leng)      4*leng^2*c + (c1*4*leng^2) + (6*c2*leng^2)];

 
% rotation matrix
 r=[ cos(beta)  sin(beta)  0   0          0         0;...
    -sin(beta)  cos(beta)  0   0          0         0;...
     0          0          1   0          0         0;...
     0          0          0   cos(beta)  sin(beta) 0;...
     0          0          0  -sin(beta)  cos(beta) 0;...
     0          0          0   0          0         1];

 
% stiffness matrix at the global axis
 k=r'*kl*r;


% % consistent mass matrix in the local axis
% 
%     mm=mtot*leng/420;
%     ma=mtot*leng/6;
%     ml=[2*ma  0           0            ma    0            0;...
%         0     156*mm      22*leng*mm   0     54*mm       -13*leng*mm;...
%         0     22*leng*mm  4*leng^2*mm  0     13*leng*mm  -3*leng^2*mm;...
%         ma    0           0            2*ma  0            0;...
%         0     54*mm       13*leng*mm   0     156*mm      -22*leng*mm;...
%         0    -13*leng*mm -3*leng^2*mm  0    -22*leng*mm   4*leng^2*mm];
% lumped mass matrix in the local axis
    mm1=(mtot*leng+macc)/2;
    mm2=mtot*leng/2;
    alfa=0; %between 0 and 1/100
    rot1=(mtot*leng+macc)*alfa*leng^2;
    rot2=mtot*leng*alfa*leng^2;
    
    ml=[mm1   0       0        0       0       0;...
        0     mm1     0        0       0       0;...
        0     0      rot1      0       0       0;...
        0     0       0        mm2     0       0;...
        0     0       0        0       mm2     0;...
        0     0       0        0       0       rot2];
 
% mass in the global system
    m=r'*ml*r;
