%----------------------------------------------------------------------
% Matlab program to plot the static configuration calculated by riflex
%
% Data source        : MariTek experiment (2001) 
% System description : Steel Catenary Riser (SCR) - Simply supported
%                      
%  Modelling          : Standard system SA
%  Cross section      : CRS1
% 
%  Created by         : Raed Lubbad    
%  Date               : 28-04-2009   Version : 3.0
%  Comments           : 
%  Last modified by   : Ingrid Simensen
%  Date               : 10-06-2015
%----------------------------------------------------------------------

clc, clear all, close all
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Load Riflex obtained configuration
n='NoLoad_stamod_cable_mass1.mpf';o='Static XZ configuration';p='NoLoad_stamod_cable_mass1.mpf';q='Static forces';r='mass1';
%n='NoLoad_stamod_cable_mass2.mpf';o='Static XZ configuration';p='NoLoad_stamod_cable_mass2.mpf';q='Static forces';r='mass2';
%n='NoLoad_stamod_cable_mass3.mpf';o='Static XZ configuration';p='NoLoad_stamod_cable_mass3.mpf';q='Static forces';r='mass3';
%n='NoLoad_stamod_cable_mass4.mpf';o='Static XZ configuration';p='NoLoad_stamod_cable_mass4.mpf';q='Static forces';r='mass4';
%n='NoLoad_stamod_cable_mass5.mpf';o='Static XZ configuration';p='NoLoad_stamod_cable_mass5.mpf';q='Static forces';r='mass5';
%n='NoLoad_stamod_cable_massExt.mpf';o='Static XZ configuration';p='NoLoad_stamod_cable_mass6.mpf';q='Static forces';r='massExt';


Nel   = 307;           % Number of elements used for FEM
L     = 12.5;          % The length of the SCR [m]

XZ    = get_matrix(n,o);
ST    = get_matrix(p,q);

x     = XZ(:,1);               % nodes x-coordinate (0 at TDP)    [m]
z     = XZ(:,2)-XZ(1,2);       % nodes z-coordinate (0 at TDP)    [m]
s     = ST(:,1);               % elements s-coordinate (0 at TDP) [m]
T     = ST(:,2);               % elements effective tension       [N]

x    = x(2:length(x)-1); x(1)=0; 
z    = z(2:length(z)-1);
ds   = L/Nel;
s    = s(1:length(s)-1); s(2:length(s)) = s(2:length(s))+ ds/2; 
T    = T(1:length(T)-1);

theta = zeros(length(x),1);        % elements slope angle [rad]
theta(2:length(theta)) = atan(diff(z)./diff(x));     theta(1) = theta(2);


figure
subplot(2,1,1)
plot(x,z)
xlabel(' x-coordinate [m]' )
ylabel(' z-coordinate [m]' )
subplot(2,1,2)
plot(s,T)
xlabel(' s-coordinate [m]' )
ylabel(' Effective tension [N]' )

% (Data from MarinTek 2001)
% ------------------
D  = 14e-3;         % Riser outer diameter [m]
t  = 0.45e-3;       % Riser wall thickness [m]
m  = 0.357;         % mass per unit length of the steel riser(Rs*As) [kg/m]
Ri = 0;             % Density of the inner fluid [kg/m^3]
Rw = 1000;          % Density of sea water [kg/m^3]
g  = 9.81;          % Acceleration of gravity [m/s^2]

EA = 2.01e6;        % Axial stiffness [N]
EI = 46.2;          % Bending stiffness [Nm^2]

% Pre-calculation
% ---------------
Ae = (pi/4)*D^2;    % Riser external cross sectionalarea [m^2] 
Di = D - 2*t;       % riser internal diameter [m]
Ai = (pi/4)*Di^2;   % Riser internal cross sectional area [m^2]

w = m*g + Ri*g*Ai - Rw*g*Ae;   % Riser wet weight per unit weight [N/m]

z_top = z(length(z));
H     = T(1)*cos(theta(1));
zd    = tan(theta);

filename=['Static_Beam_NoLoad_',r,'_calc'];

save(filename,'w','z_top','H','x', 's','z','zd','theta','T')


disp([' FEM_Beam (Riflex solution) :'])
disp('------------------------------')
disp([' Total length between pinned end [L]       =      ' ,num2str(s(length(s))), '   [m]'])
disp([' Mass pr unit length including content [m] =      ' ,num2str(m), '  [kg]'])
disp([' Outer diameter (D)                        =      ' ,num2str(D), '  [m]'])
disp([' Wall thickness (t)                        =      ' ,num2str(t), '  [m]'])
disp([' Axial stiffness (EA)                      =      ' ,num2str(EA), ' [N]'])
disp([' Bending stiffness (EI)                    =      ' ,num2str(EI), ' [N.m^2]'])
disp([' Horizontal distance between riser ends    =      ' ,num2str(x(length(x))), '  [m]'])
disp([' Vertical distance between riser ends      =      ' ,num2str(z(length(z))), '  [m]'])
disp(' ')
disp([' Tension, Upper end                        =      ' ,num2str(T(length(T))), '  [N]'])
disp([' Tension, lower end                        =      ' ,num2str(T(1)), '  [N]'])
disp([' Angle from vertical, upper end            =      ' ,num2str(90-(180/pi)*theta(length(theta))), '  [deg]'])
disp([' Angle from vertical, lower end            =      ' ,num2str(90-(180/pi)*theta(1)), '  [deg]'])


